==> VennDiagram_1.0.0.tar.gz: VennDiagram/R/draw.111A.R <==
### FUNCTION TO DRAW SPECIAL CASE 111A #############################################################
draw.111A <- function(a1, a2, a3, a4, a5, a6, a7, category = rep("", 3), reverse = FALSE, cat.default.pos = "outer", lwd = rep(2, 3), lty = rep("solid", 3), col = rep("black", 3), label.col = rep("black", 7), cex = rep(1, 7), fontface = rep("plain", 7), fontfamily = rep("serif", 7), cat.pos = c(-40, 40, 180), cat.dist = c(0.05, 0.05, 0.025), cat.col = rep("black", 3), cat.cex = rep(1, 3), cat.fontface = rep("plain", 3), cat.fontfamily = rep("serif", 3), cat.just = list(c(0.5, 1), c(0.5, 1), c(0.5, 0)), cat.prompts = FALSE, fill = NULL, alpha = rep(0.5, 3), ...) {
	
	i <- 1;
	while (i <= 3) {
		tmp <- rotate.sp(c(a1, a2, a3, a4, a5, a6, a7), category, i, reverse);
		if (tmp[[1]][7] == 0 & tmp[[1]][4] == 0) {i <- 4}
		if (tmp[[1]][7] == 0 & tmp[[1]][6] == 0) {i <- 5}
		if (tmp[[1]][7] != 0) {i <- i + 1}
		}
	if (i == 5) { tmp <- rotate.sp(tmp[[1]], tmp[[2]], 1, reverse = TRUE) }
	a1 <- tmp[[1]][1];
	a2 <- tmp[[1]][2];
	a3 <- tmp[[1]][3];
	a6 <- tmp[[1]][6];
	category <- tmp[[2]];
	
	x.centre.1 <- 0.32;
	y.centre.1 <- 0.5;
	r1 <- 0.27;
	x.centre.2 <- 0.68;
	y.centre.2 <- 0.5;
	r2 <- 0.27;
	x.centre.3 <- 0.76;
	y.centre.3 <- 0.5;
	r3 <- 0.14;
	
	a1.x.pos <- 0.27;
	a1.y.pos <- 0.5;
	a2.x.pos <- 0.5;
	a2.y.pos <- 0.5;
	a3.x.pos <- 0.68;
	a3.y.pos <- 0.705;
	a6.x.pos <- 0.76;
	a6.y.pos <- 0.5;
	
	return(
		draw.sp.case(
			area.list = c(a1, a2, a3, 0, 0, a6, 0),
			enabled.areas = c(1, 2, 3, 6),
			area.x = c(a1.x.pos, a2.x.pos, a3.x.pos, 0, 0, a6.x.pos, 0),
			area.y = c(a1.y.pos, a2.y.pos, a3.y.pos, 0, 0, a6.y.pos, 0),
			attach.label.to = c(1, 3, 6),
			x.centres = c(x.centre.1, x.centre.2, x.centre.3),
			y.centres = c(y.centre.1, y.centre.2, y.centre.3),
			a.list = c(r1, r2, r3),
			b.list = c(r1, r2, r3),
			straight.reverse = TRUE,
			reverse = reverse,
			category = category,
			cat.default.pos = cat.default.pos, 
			lwd = lwd, 
			lty = lty, 
			col = col, 
			label.col = label.col, 
			cex = cex, 
			fontface = fontface, 
			fontfamily = fontfamily, 
			cat.pos = cat.pos, 
			cat.dist = cat.dist, 
			cat.col = cat.col, 
			cat.cex = cat.cex, 
			cat.fontface = cat.fontface, 
			cat.fontfamily = cat.fontfamily, 
			cat.just = cat.just,
			fill = fill, 
			alpha = alpha,
			...
		)
	)
}

==> VennDiagram_1.2.0.tar.gz: VennDiagram/R/draw.111A.R <==
### FUNCTION TO DRAW SPECIAL CASE 111A #############################################################
draw.111A <- function(a1, a2, a3, a4, a5, a6, a7, category = rep("", 3), reverse = FALSE, cat.default.pos = "outer", lwd = rep(2, 3), lty = rep("solid", 3), col = rep("black", 3), label.col = rep("black", 7), cex = rep(1, 7), fontface = rep("plain", 7), fontfamily = rep("serif", 7), cat.pos = c(-40, 40, 180), cat.dist = c(0.05, 0.05, 0.025), cat.col = rep("black", 3), cat.cex = rep(1, 3), cat.fontface = rep("plain", 3), cat.fontfamily = rep("serif", 3), cat.just = list(c(0.5, 1), c(0.5, 1), c(0.5, 0)), cat.prompts = FALSE, fill = NULL, alpha = rep(0.5, 3), ...) {
	
	i <- 1;
	while (i <= 3) {
		tmp <- VennDiagram::rotate.sp(c(a1, a2, a3, a4, a5, a6, a7), category, i, reverse);
		if (tmp[[1]][7] == 0 & tmp[[1]][4] == 0) {i <- 4}
		if (tmp[[1]][7] == 0 & tmp[[1]][6] == 0) {i <- 5}
		if (tmp[[1]][7] != 0) {i <- i + 1}
		}
	if (i == 5) { tmp <- rotate.sp(tmp[[1]], tmp[[2]], 1, reverse = TRUE) }
	a1 <- tmp[[1]][1];
	a2 <- tmp[[1]][2];
	a3 <- tmp[[1]][3];
	a6 <- tmp[[1]][6];
	category <- tmp[[2]];
	
	x.centre.1 <- 0.32;
	y.centre.1 <- 0.5;
	r1 <- 0.27;
	x.centre.2 <- 0.68;
	y.centre.2 <- 0.5;
	r2 <- 0.27;
	x.centre.3 <- 0.76;
	y.centre.3 <- 0.5;
	r3 <- 0.14;
	
	a1.x.pos <- 0.27;
	a1.y.pos <- 0.5;
	a2.x.pos <- 0.5;
	a2.y.pos <- 0.5;
	a3.x.pos <- 0.68;
	a3.y.pos <- 0.705;
	a6.x.pos <- 0.76;
	a6.y.pos <- 0.5;
	
	return(
		VennDiagram::draw.sp.case(
			area.list = c(a1, a2, a3, 0, 0, a6, 0),
			enabled.areas = c(1, 2, 3, 6),
			area.x = c(a1.x.pos, a2.x.pos, a3.x.pos, 0, 0, a6.x.pos, 0),
			area.y = c(a1.y.pos, a2.y.pos, a3.y.pos, 0, 0, a6.y.pos, 0),
			attach.label.to = c(1, 3, 6),
			x.centres = c(x.centre.1, x.centre.2, x.centre.3),
			y.centres = c(y.centre.1, y.centre.2, y.centre.3),
			a.list = c(r1, r2, r3),
			b.list = c(r1, r2, r3),
			straight.reverse = TRUE,
			reverse = reverse,
			category = category,
			cat.default.pos = cat.default.pos, 
			lwd = lwd, 
			lty = lty, 
			col = col, 
			label.col = label.col, 
			cex = cex, 
			fontface = fontface, 
			fontfamily = fontfamily, 
			cat.pos = cat.pos, 
			cat.dist = cat.dist, 
			cat.col = cat.col, 
			cat.cex = cat.cex, 
			cat.fontface = cat.fontface, 
			cat.fontfamily = cat.fontfamily, 
			cat.just = cat.just,
			fill = fill, 
			alpha = alpha,
			...
		)
	)
}
